@@ -1,4 +1,4 @@
 from .abstractShapeManager import *
-from .directions import *
-from .cardinalDirectons import *
+from .direction import *
+from .cardinalDirections import *
 from .transform import *
